==> ocstore25_4_23.zip: OcStore/OcStore/global.h <==
#pragma once
// MFC
#include <SDKDDKVer.h>//汾
#include <afxwin.h>//MFCı׼
#include <afxdlgs.h>
// C++
#include <set>
#include <map>
#include <unordered_map>
#include <list>
#include <vector>
#include <string>
#include <queue>
#include <mutex>
// SQLite
#include <sqlite3.h>
// TinyXML
#include <tinyxml2.h>
// MyDXRenderer
#include <MyDX11Renderer.h>
//궨
#define LOADHOTKEY(id) hAccel = ::LoadAccelerators(AfxGetApp()->m_hInstance, MAKEINTRESOURCE(id))//ȼ
#define HOTKEYPROC if (TranslateAccelerator(GetSafeHwnd(), hAccel, pMsg))return TRUE;return CDialog::PreTranslateMessage(pMsg)
void UTF16ToUTF8(const wchar_t* wstr, std::vector<char>*outData, int* outLen = nullptr);
void UTF16ToGBK(const wchar_t* wstr, std::vector<char>*outData, int* outLen = nullptr);
void UTF8ToUTF16(const char* str, std::vector<wchar_t>*outData, int* outLen = nullptr);
void GBKToUTF16(const char* str, std::vector<wchar_t>*outData, int* outLen = nullptr);
#define DPISCALE(x) ((x)*dpi/100)
//ѹ
void InitZLib();
void ZLibCompressData(std::vector<BYTE>*outData, size_t * outLen, const void* source, size_t sourceLen);//ѹ
void ZLibUncompressData(std::vector<BYTE>*outData, size_t * outLen, const void* source, size_t sourceLen);//ѹ

void MoveToNeighborRect(CRect& rcDst, CRect& rcSrc, int directionDst, int directionSrc);
void MoveWindow(CWnd* wnd, int x, int y);
void LoadResourceTexture(MyDX11Renderer * pRenderer, UINT res, ID3D11Texture2D * *outTexture, ID3D11ShaderResourceView * *outSRV);
float MyFar(float myFar);//ӣ۾ƶ

void Base64Encode(std::string & out, const void* data, size_t dataSize);
bool Base64Decode(std::vector<BYTE>&out, const char* base64Str);

int GetSafePxa(int X, int Y, std::vector<LONG>&pxmData, std::vector<int>&pxaData, int pxmArr_w, int pxmArr_h);

==> ocstore25_7_23.zip: OcStore/OcStore/global.h <==
#pragma once
// MFC
#include <SDKDDKVer.h>//汾
#include <afxwin.h>//MFCı׼
#include <afxdlgs.h>
// C++
#include <set>
#include <map>
#include <unordered_map>
#include <list>
#include <vector>
#include <string>
#include <queue>
#include <mutex>
// SQLite
#include <sqlite3.h>
// TinyXML
#include <tinyxml2.h>
// MyDXRenderer
#include <MyDX11Renderer.h>
//궨
#define LOADHOTKEY(id) hAccel = ::LoadAccelerators(AfxGetApp()->m_hInstance, MAKEINTRESOURCE(id))//ȼ
#define HOTKEYPROC if (TranslateAccelerator(GetSafeHwnd(), hAccel, pMsg))return TRUE;return CDialog::PreTranslateMessage(pMsg)
void UTF16ToUTF8(const wchar_t* wstr, std::vector<char>*outData, int* outLen = nullptr);
void UTF8ToUTF16(const char* str, std::vector<wchar_t>*outData, int* outLen = nullptr);
#define DPISCALE(x) ((x)*dpi/100)
//ѹ
void InitZLib();
void ZLibCompressData(std::vector<BYTE>*outData, size_t * outLen, const void* source, size_t sourceLen);//ѹ
void ZLibUncompressData(std::vector<BYTE>*outData, size_t * outLen, const void* source, size_t sourceLen);//ѹ

void MoveToNeighborRect(CRect& rcDst, CRect& rcSrc, int directionDst, int directionSrc);
void MoveWindow(CWnd* wnd, int x, int y);
void LoadResourceTexture(MyDX11Renderer * pRenderer, UINT res, ID3D11Texture2D * *outTexture, ID3D11ShaderResourceView * *outSRV);
float MyFar(float myFar);//ӣ۾ƶ

void Base64Encode(std::string & out, const void* data, size_t dataSize);
bool Base64Decode(std::vector<BYTE>&out, const char* base64Str);

int GetSafePxa(int X, int Y, std::vector<LONG>&pxmData, std::vector<int>&pxaData, int pxmArr_w, int pxmArr_h);
void MyWinExec(std::wstring cmd);
